@@ -3,12 +3,12 @@ from enum import Enum
 
 class APIErrorCode(str, Enum):
     CSRF_CHECK_FAILED = "CSRF_CHECK_FAILED"
-    CANT_DETERMINE_VALID_ACCOUNT = "CANT_DETERMINE_VALID_ACCOUNT"
+    CANT_DETERMINE_VALID_WORKSPACE = "CANT_DETERMINE_VALID_WORKSPACE"
 
-    ACCOUNT_CREATE_MISSING_DATABASE_SETTINGS = (
-        "ACCOUNT_CREATE_MISSING_DATABASE_SETTINGS"
+    WORKSPACE_CREATE_MISSING_DATABASE_SETTINGS = (
+        "WORKSPACE_CREATE_MISSING_DATABASE_SETTINGS"
     )
-    ACCOUNT_DB_CONNECTION_ERROR = "ACCOUNT_DB_CONNECTION_ERROR"
+    WORKSPACE_DB_CONNECTION_ERROR = "WORKSPACE_DB_CONNECTION_ERROR"
 
     CLIENT_CREATE_UNKNOWN_TENANT = "CLIENT_CREATE_UNKNOWN_TENANT"
 
